==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapWebAuthnPolicyEntityFields.java <==
package org.keycloak.models.map.realm.entity;
public enum MapWebAuthnPolicyEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> {
    ACCEPTABLE_AAGUIDS {
        public static final String FIELD_NAME = "AcceptableAaguids";
        public static final String FIELD_NAME_DASHED = "acceptable-aaguids";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.List.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public java.util.List<String> get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (java.util.List<String>) e.getAcceptableAaguids();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setAcceptableAaguids((java.util.List<String>) value);
        }
    },
    ATTESTATION_CONVEYANCE_PREFERENCE {
        public static final String FIELD_NAME = "AttestationConveyancePreference";
        public static final String FIELD_NAME_DASHED = "attestation-conveyance-preference";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setAttestationConveyancePreference((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getAttestationConveyancePreference();
        }
    },
    AUTHENTICATOR_ATTACHMENT {
        public static final String FIELD_NAME = "AuthenticatorAttachment";
        public static final String FIELD_NAME_DASHED = "authenticator-attachment";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getAuthenticatorAttachment();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setAuthenticatorAttachment((String) value);
        }
    },
    AVOID_SAME_AUTHENTICATOR_REGISTER {
        public static final String FIELD_NAME = "AvoidSameAuthenticatorRegister";
        public static final String FIELD_NAME_DASHED = "avoid-same-authenticator-register";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setAvoidSameAuthenticatorRegister((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (Boolean) e.isAvoidSameAuthenticatorRegister();
        }
    },
    CREATE_TIMEOUT {
        public static final String FIELD_NAME = "CreateTimeout";
        public static final String FIELD_NAME_DASHED = "create-timeout";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (Integer) e.getCreateTimeout();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setCreateTimeout((Integer) value);
        }
    },
    REQUIRE_RESIDENT_KEY {
        public static final String FIELD_NAME = "RequireResidentKey";
        public static final String FIELD_NAME_DASHED = "require-resident-key";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getRequireResidentKey();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setRequireResidentKey((String) value);
        }
    },
    RP_ENTITY_NAME {
        public static final String FIELD_NAME = "RpEntityName";
        public static final String FIELD_NAME_DASHED = "rp-entity-name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setRpEntityName((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getRpEntityName();
        }
    },
    RP_ID {
        public static final String FIELD_NAME = "RpId";
        public static final String FIELD_NAME_DASHED = "rp-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setRpId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getRpId();
        }
    },
    SIGNATURE_ALGORITHMS {
        public static final String FIELD_NAME = "SignatureAlgorithms";
        public static final String FIELD_NAME_DASHED = "signature-algorithms";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.List.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setSignatureAlgorithms((java.util.List<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.List<String> get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (java.util.List<String>) e.getSignatureAlgorithms();
        }
    },
    USER_VERIFICATION_REQUIREMENT {
        public static final String FIELD_NAME = "UserVerificationRequirement";
        public static final String FIELD_NAME_DASHED = "user-verification-requirement";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getUserVerificationRequirement();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setUserVerificationRequirement((String) value);
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapWebAuthnPolicyEntityFields.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapWebAuthnPolicyEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity> {
    ACCEPTABLE_AAGUIDS {
        public static final String FIELD_NAME = "AcceptableAaguids";
        public static final String FIELD_NAME_DASHED = "acceptable-aaguids";
        public static final String FIELD_NAME_CAMEL_CASE = "acceptableAaguids";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.List.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setAcceptableAaguids((java.util.List<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.List<String> get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (java.util.List<String>) e.getAcceptableAaguids();
        }
    },
    ATTESTATION_CONVEYANCE_PREFERENCE {
        public static final String FIELD_NAME = "AttestationConveyancePreference";
        public static final String FIELD_NAME_DASHED = "attestation-conveyance-preference";
        public static final String FIELD_NAME_CAMEL_CASE = "attestationConveyancePreference";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getAttestationConveyancePreference();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setAttestationConveyancePreference((String) value);
        }
    },
    AUTHENTICATOR_ATTACHMENT {
        public static final String FIELD_NAME = "AuthenticatorAttachment";
        public static final String FIELD_NAME_DASHED = "authenticator-attachment";
        public static final String FIELD_NAME_CAMEL_CASE = "authenticatorAttachment";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setAuthenticatorAttachment((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getAuthenticatorAttachment();
        }
    },
    AVOID_SAME_AUTHENTICATOR_REGISTER {
        public static final String FIELD_NAME = "AvoidSameAuthenticatorRegister";
        public static final String FIELD_NAME_DASHED = "avoid-same-authenticator-register";
        public static final String FIELD_NAME_CAMEL_CASE = "avoidSameAuthenticatorRegister";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (Boolean) e.isAvoidSameAuthenticatorRegister();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setAvoidSameAuthenticatorRegister((Boolean) value);
        }
    },
    CREATE_TIMEOUT {
        public static final String FIELD_NAME = "CreateTimeout";
        public static final String FIELD_NAME_DASHED = "create-timeout";
        public static final String FIELD_NAME_CAMEL_CASE = "createTimeout";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (Integer) e.getCreateTimeout();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setCreateTimeout((Integer) value);
        }
    },
    REQUIRE_RESIDENT_KEY {
        public static final String FIELD_NAME = "RequireResidentKey";
        public static final String FIELD_NAME_DASHED = "require-resident-key";
        public static final String FIELD_NAME_CAMEL_CASE = "requireResidentKey";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getRequireResidentKey();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setRequireResidentKey((String) value);
        }
    },
    RP_ENTITY_NAME {
        public static final String FIELD_NAME = "RpEntityName";
        public static final String FIELD_NAME_DASHED = "rp-entity-name";
        public static final String FIELD_NAME_CAMEL_CASE = "rpEntityName";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getRpEntityName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setRpEntityName((String) value);
        }
    },
    RP_ID {
        public static final String FIELD_NAME = "RpId";
        public static final String FIELD_NAME_DASHED = "rp-id";
        public static final String FIELD_NAME_CAMEL_CASE = "rpId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getRpId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setRpId((String) value);
        }
    },
    SIGNATURE_ALGORITHMS {
        public static final String FIELD_NAME = "SignatureAlgorithms";
        public static final String FIELD_NAME_DASHED = "signature-algorithms";
        public static final String FIELD_NAME_CAMEL_CASE = "signatureAlgorithms";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.List.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setSignatureAlgorithms((java.util.List<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.List<String> get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (java.util.List<String>) e.getSignatureAlgorithms();
        }
    },
    USER_VERIFICATION_REQUIREMENT {
        public static final String FIELD_NAME = "UserVerificationRequirement";
        public static final String FIELD_NAME_DASHED = "user-verification-requirement";
        public static final String FIELD_NAME_CAMEL_CASE = "userVerificationRequirement";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e, T value) {
            e.setUserVerificationRequirement((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapWebAuthnPolicyEntity e) {
            return (String) e.getUserVerificationRequirement();
        }
    },
}
